@@ -31,6 +31,21 @@ def get(session, response):
     return session.get
 
 
+@pytest.fixture
+def tuxauth(mocker):
+    get = mocker.Mock(
+        return_value=mocker.Mock(
+            **{
+                "json.return_value": {
+                    "UserDetails": {"Groups": ["tuxsuite"], "Name": "tux"}
+                }
+            }
+        )
+    )
+    mocker.patch("tuxsuite.config.requests.get", get)
+    return get
+
+
 @pytest.fixture
 def sample_token():
     return "Q9qMlmkjkIuIGmEAw-Mf53i_qoJ8Z2eGYCmrNx16ZLLQGrXAHRiN2ce5DGlAebOmnJFp9Ggcq9l6quZdDTtrkw"
