@@ -143,6 +143,7 @@ def build_attrs():
         "toolchain": "gcc-9",
         "token": "test_token",
         "kbapi_url": "http://test/foo",
+        "tuxapi_url": "http://tuxapi",
         "kernel_image": "Image",
     }
 
@@ -593,6 +594,7 @@ def build_set(build_attrs, builds):
         git_repo=build_attrs["git_repo"],
         git_ref=build_attrs["git_ref"],
         kbapi_url=build_attrs["kbapi_url"],
+        tuxapi_url=build_attrs["tuxapi_url"],
         token=build_attrs["token"],
     )
 
