@@ -38,7 +38,7 @@ def test_build_usage():
 
 
 @pytest.fixture
-def tuxsuite_config(tmp_path, monkeypatch):
+def tuxsuite_config(tmp_path, monkeypatch, tuxauth):
     c = tmp_path / "config.ini"
     with c.open("w") as f:
         f.write("[default]\n")
@@ -285,7 +285,7 @@ sets:
 
 
 @pytest.fixture
-def tux_config(tmp_path):
+def tux_config(tmp_path, tuxauth):
     config = tmp_path / "buildset.yaml"
     with config.open("w") as f:
         f.write(sample_build_set)
