@@ -25,6 +25,8 @@ class Configurable:
             kwargs["token"] = cfg.auth_token
         if "kbapi_url" not in kwargs:
             kwargs["kbapi_url"] = cfg.kbapi_url
+        if "tuxapi_url" not in kwargs:
+            kwargs["tuxapi_url"] = cfg.tuxapi_url
         if "group" not in kwargs:
             kwargs["group"] = cfg.group
         if "project" not in kwargs:
@@ -44,3 +46,10 @@ class BuildSet(Configurable, build.BuildSet):
     This class represents a set of builds that can be triggered and watched
     simultaneously.
     """
+
+
+class Test(Configurable, build.Test):
+    """
+    This class represents individual tests. It should be used to trigger
+    tests, and optionally wait for them to finish.
+    """
