@@ -112,7 +112,7 @@ def common_options(required):
         ),
         option(
             "--toolchain",
-            help="Toolchain [gcc-8|gcc-9|gcc-10|clang-10|clang-11|clang-nightly]",
+            help="Toolchain [gcc-8|gcc-9|gcc-10|clang-10|clang-11|clang-12|clang-nightly]",
         ),
         option(
             "--build-name",
@@ -309,5 +309,48 @@ def build_set(
         sys.exit(1)
 
 
+DEVICES = [
+    "qemu-arm",
+    "qemu-arm64",
+    "qemu-i386",
+    "qemu-mips64",
+    "qemu-ppc64",
+    "qemu-riscv64",
+    "qemu-x86_64",
+]
+TESTS = ["ltp-smoke"]
+
+
+@cli.command(help="Test a kernel", short_help="Test a kernel")
+@click.option("--device", help="Device type", required=True, type=click.Choice(DEVICES))
+@click.option("--kernel", help="URL of the kernel to test", required=True, type=str)
+@click.option("--tests", help="Comma separated list of tests", type=str, default="")
+def test(device, kernel, tests):
+    tests = [test for test in tests.split(",") if test]
+    invalid_tests = [test for test in tests if test not in TESTS]
+    if invalid_tests:
+        raise click.ClickException(
+            "Invalid tests [{}], only valid tests are: [{}]".format(
+                ", ".join(invalid_tests), ", ".join(TESTS)
+            )
+        )
+    info("Testing {} on {} with {}".format(kernel, device, ", ".join(["boot"] + tests)))
+
+    try:
+        test = tuxsuite.Test(device=device, kernel=kernel, tests=tests)
+    except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
+        error(e)
+
+    try:
+        test.test()
+    except tuxsuite.exceptions.BadRequest as e:
+        raise (click.ClickException(str(e)))
+    test_result = wait_for_object(test)
+
+    # If the test did not pass, exit with exit code of 1
+    if not test_result:
+        sys.exit(1)
+
+
 def main():
     cli.main(prog_name="tuxsuite")
