@@ -6,6 +6,7 @@ from os.path import expanduser
 import configparser
 import logging
 import re
+import uuid
 import yaml
 from tuxsuite import requests
 
@@ -64,12 +65,18 @@ class Config:
 
             Fields:
                 token
+                group (optional)
+                project (optional)
                 api_url (optional)
+                tuxapi_url (optional)
+                tuxauth_url (optional)
         """
 
         self.default_api_url = (
             "https://api.tuxbuild.com/v1"  # Use production v1 if no url is specified
         )
+        self.tuxapi_url = "https://tuxapi.tuxsuite.com"
+        self.tuxauth_url = "https://auth.tuxsuite.com"
         self.tuxsuite_env = getenv("ENV", "default")
 
         (
@@ -88,6 +95,8 @@ class Config:
             (
                 self.auth_token,
                 self.kbapi_url,
+                self.tuxapi_url,
+                self.tuxauth_url,
                 self.group,
                 self.project,
             ) = self._get_config_from_config(config_path)
@@ -107,6 +116,7 @@ class Config:
 
     def _get_config_from_config(self, config_path):
         path = expanduser(config_path)
+        defaults = os.path.abspath(os.path.join(path, "..", "defaults.ini"))
         try:
             open(path, "r")  # ensure file exists and is readable
         except Exception as e:
@@ -114,7 +124,8 @@ class Config:
 
         config = configparser.ConfigParser()
 
-        config.read(path)
+        # Load the defaults config (if it exists) and path
+        config.read([defaults, path])
         if not config.has_section(self.tuxsuite_env):
             raise tuxsuite.exceptions.InvalidConfiguration(
                 "Error, missing section [{}] from config file '{}'".format(
@@ -124,10 +135,42 @@ class Config:
         kbapi_url = (
             config[self.tuxsuite_env].get("api_url", self.default_api_url).rstrip("/")
         )
+        tuxapi_url = (
+            config[self.tuxsuite_env].get("tuxapi_url", self.tuxapi_url).rstrip("/")
+        )
+        tuxauth_url = (
+            config[self.tuxsuite_env].get("tuxauth_url", self.tuxauth_url).rstrip("/")
+        )
         auth_token = config[self.tuxsuite_env].get("token", None)
         group = config[self.tuxsuite_env].get("group", None)
         project = config[self.tuxsuite_env].get("project", None)
-        return (auth_token, kbapi_url, group, project)
+
+        # Add default group and project from tuxauth
+        if auth_token and (group is None or project is None):
+            ret = requests.get(
+                f"{tuxauth_url}/v1/tokens/{uuid.uuid3(uuid.NAMESPACE_DNS, auth_token)}"
+            )
+            try:
+                user = ret.json()["UserDetails"]
+            except Exception as e:
+                raise tuxsuite.exceptions.CantGetConfiguration(
+                    f"Unable to get default group and project: {e}"
+                )
+
+            default_config = configparser.ConfigParser()
+            default_config.read(defaults)
+            if not default_config.has_section(self.tuxsuite_env):
+                default_config.add_section(self.tuxsuite_env)
+            if group is None:
+                group = user["Groups"][0]
+                default_config.set(self.tuxsuite_env, "group", group)
+            if project is None:
+                project = user["Name"]
+                default_config.set(self.tuxsuite_env, "project", project)
+
+            with open(defaults, "w") as f_out:
+                default_config.write(f_out)
+        return (auth_token, kbapi_url, tuxapi_url, tuxauth_url, group, project)
 
     def _get_config_from_env(self):
         # Check environment for TUXSUITE_TOKEN
